package VMOMI::ArrayUpdateOperation;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
